@@ -1,10 +1,10 @@
 #!/usr/bin/python3
 
-import importstest.directory_finder
+import directory_finder
 
 
 def main():
-    input_folder = importstest.directory_finder.LocateDirectory()
+    input_folder = directory_finder.LocateDirectory()
     input_dir = input_folder.input_dir_pointer()
     main_dir = input_folder.using_path_singleton()
 
